@@ -12,6 +12,7 @@ from neolib.shop.UserBackShop import UserBackShop
 from neolib.user.Bank import Bank
 from neolib.user.hooks.UserDetails import UserDetails
 from neolib.user.hooks.LoginCheck import LoginCheck
+from neolib.user.hooks.NSTHook import NSTHook
 from neolib.user.Profile import Profile
 
 
@@ -148,6 +149,7 @@ class User(NeolibBase):
         # Setup default hooks
         self.add_hook(UserDetails)
         self.add_hook(LoginCheck)
+        self.add_hook(NSTHook)
 
     def login(self, birthday=None):
         """Performs a login and returns the result
